@@ -11,22 +11,20 @@ import xarray as xr
 from pydantic import BaseModel, Field
 
 from nowcasting_dataset.config.model import Configuration
-from nowcasting_dataset.data_sources.datetime.datetime_model import DatetimeML, Datetime
-from nowcasting_dataset.data_sources.gsp.gsp_model import GSPML, GSP
-from nowcasting_dataset.data_sources.metadata.metadata_model import MetadataML, Metadata
+from nowcasting_dataset.data_sources.datetime.datetime_model import Datetime
+from nowcasting_dataset.data_sources.gsp.gsp_model import GSP
+from nowcasting_dataset.data_sources.metadata.metadata_model import Metadata
 from nowcasting_dataset.data_sources.nwp.nwp_model import (
-    NWPML,
     NWP,
 )
-from nowcasting_dataset.data_sources.pv.pv_model import PVML, PV
-from nowcasting_dataset.data_sources.satellite.satellite_model import SatelliteML, Satellite
-from nowcasting_dataset.data_sources.sun.sun_model import SunML, Sun
-from nowcasting_dataset.data_sources.topographic.topographic_model import TopographicML, Topographic
+from nowcasting_dataset.data_sources.pv.pv_model import PV
+from nowcasting_dataset.data_sources.satellite.satellite_model import Satellite
+from nowcasting_dataset.data_sources.sun.sun_model import Sun
+from nowcasting_dataset.data_sources.topographic.topographic_model import Topographic
 from nowcasting_dataset.dataset.xr_utils import (
     register_xr_data_array_to_tensor,
     register_xr_data_set_to_tensor,
 )
-from nowcasting_dataset.time import make_random_time_vectors
 from nowcasting_dataset.data_sources.fake import (
     datetime_fake,
     metadata_fake,
@@ -184,14 +182,14 @@ class Example(BaseModel):
     Note that this is currently not really used
     """
 
-    metadata: Optional[MetadataML]
-    satellite: Optional[SatelliteML]
-    topographic: Optional[TopographicML]
-    pv: Optional[PVML]
-    sun: Optional[SunML]
-    gsp: Optional[GSPML]
-    nwp: Optional[NWPML]
-    datetime: Optional[DatetimeML]
+    metadata: Optional[Metadata]
+    satellite: Optional[Satellite]
+    topographic: Optional[Topographic]
+    pv: Optional[PV]
+    sun: Optional[Sun]
+    gsp: Optional[GSP]
+    nwp: Optional[NWP]
+    datetime: Optional[Datetime]
 
     @property
     def data_sources(self):
@@ -206,86 +204,3 @@ class Example(BaseModel):
             self.datetime,
             self.metadata,
         ]
-
-
-class BatchML(Example):
-    """
-    Batch data object.
-
-    Contains the following data sources
-    - gsp, satellite, topogrpahic, sun, pv, nwp and datetime.
-    Also contains metadata of the class
-
-    """
-
-    batch_size: int = Field(
-        ...,
-        g=0,
-        description="The size of this batch. If the batch size is 0, "
-        "then this item stores one data item",
-    )
-
-    @staticmethod
-    def fake(configuration: Configuration = Configuration()):
-        """Create fake batch"""
-        process = configuration.process
-
-        t0_dt, time_5, time_30 = make_random_time_vectors(
-            batch_size=process.batch_size,
-            seq_length_5_minutes=process.seq_length_5_minutes,
-            seq_length_30_minutes=process.seq_length_30_minutes,
-        )
-
-        return BatchML(
-            batch_size=process.batch_size,
-            metadata=MetadataML.fake(batch_size=process.batch_size, t0_dt=t0_dt),
-            satellite=SatelliteML.fake(
-                process.batch_size,
-                process.seq_length_5_minutes,
-                process.satellite_image_size_pixels,
-                len(process.sat_channels),
-                time_5=time_5,
-            ),
-            topographic=TopographicML.fake(
-                batch_size=process.batch_size,
-                image_size_pixels=process.satellite_image_size_pixels,
-            ),
-            pv=PVML.fake(
-                batch_size=process.batch_size,
-                seq_length_5=process.seq_length_5_minutes,
-                n_pv_systems_per_batch=128,
-                time_5=time_5,
-            ),
-            sun=SunML.fake(
-                batch_size=process.batch_size, seq_length_5=process.seq_length_5_minutes
-            ),
-            nwp=NWPML.fake(
-                batch_size=process.batch_size,
-                seq_length_5=process.seq_length_5_minutes,
-                image_size_pixels=process.nwp_image_size_pixels,
-                number_nwp_channels=len(process.nwp_channels),
-                time_5=time_5,
-            ),
-            datetime=DatetimeML.fake(
-                batch_size=process.batch_size, seq_length_5=process.seq_length_5_minutes
-            ),
-        )
-
-    @staticmethod
-    def from_batch(batch: Batch) -> BatchML:
-        """ Change batch to ML batch """
-        data_sources_names = Example.__fields__.keys()
-
-        data_sources_dict = {}
-        for data_source_name in data_sources_names:
-
-            data_source = BatchML.__fields__[data_source_name].type_
-
-            xr_dataset = getattr(batch, data_source_name)
-            if xr_dataset is not None:
-
-                data_sources_dict[data_source_name] = data_source.from_xr_dataset(xr_dataset)
-
-        data_sources_dict["batch_size"] = data_sources_dict["satellite"].batch_size
-
-        return BatchML(**data_sources_dict)
